==> ejc-jltest-api-3.0.0-20240309.002551-16-sources.jar: com/ejianc/business/jltest/orgtest/vo/PlancVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 安措费使用计划C
 *
 * @author generator
 */
public class PlancVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 安措费使用计划发文字号
    private String planName; // 安措费使用计划发文名称
    private Integer urgencyDegree; // 紧急程度（1-一般，2-急，3-特急）
    private Integer securityClass; // 密级（1-公开，2-秘密，3-机密，4-绝密）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date planDate; // 安措费使用计划发文日期
    private BigDecimal planMny; // 拟投入金额
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectCode; // 项目code
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private Long parentOrgId; // 父级组织
    private String parentOrgName; // 父级组织名称
    private String parentOrgCode; // 父级组织编码
    private Long safeteamcId; // 安全小组主键
    private String safeteamcName; // 安全小组发文名称
    private String safeteamcBillCode; // 安全小组成立发文字号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date safeteamcDate; // 安全小组发文日期
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long submitEmployeeId; // 提交人
    private String submitEmployeeName; // 提交人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private String memo; // 安措费使用计发文说明
    private Integer billState; // 单据状态（审批必须字段）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date submitDate; // 提交日期


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }

    public Integer getUrgencyDegree() {
        return urgencyDegree;
    }

    public void setUrgencyDegree(Integer urgencyDegree) {
        this.urgencyDegree = urgencyDegree;
    }

    public Integer getSecurityClass() {
        return securityClass;
    }

    public void setSecurityClass(Integer securityClass) {
        this.securityClass = securityClass;
    }

    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }

    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    @ReferSerialTransfer(referCode = "safeTeam-c")
    public Long getSafeteamcId() {
        return safeteamcId;
    }

    @ReferDeserialTransfer
    public void setSafeteamcId(Long safeteamcId) {
        this.safeteamcId = safeteamcId;
    }

    public String getSafeteamcName() {
        return safeteamcName;
    }

    public void setSafeteamcName(String safeteamcName) {
        this.safeteamcName = safeteamcName;
    }

    public String getSafeteamcBillCode() {
        return safeteamcBillCode;
    }

    public void setSafeteamcBillCode(String safeteamcBillCode) {
        this.safeteamcBillCode = safeteamcBillCode;
    }

    public Date getSafeteamcDate() {
        return safeteamcDate;
    }

    public void setSafeteamcDate(Date safeteamcDate) {
        this.safeteamcDate = safeteamcDate;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getSubmitEmployeeId() {
        return submitEmployeeId;
    }

    public void setSubmitEmployeeId(Long submitEmployeeId) {
        this.submitEmployeeId = submitEmployeeId;
    }

    public String getSubmitEmployeeName() {
        return submitEmployeeName;
    }

    public void setSubmitEmployeeName(String submitEmployeeName) {
        this.submitEmployeeName = submitEmployeeName;
    }

    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    @ReferDeserialTransfer

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Date getSubmitDate() {
        return submitDate;
    }

    public void setSubmitDate(Date submitDate) {
        this.submitDate = submitDate;
    }

}

==> ejc-jltest-api-3.0.0-20240309.072811-28-sources.jar: com/ejianc/business/jltest/orgtest/vo/PlancVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 安措费使用计划C
 *
 * @author generator
 */
public class PlancVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 安措费使用计划发文字号
    private String planName; // 安措费使用计划发文名称
    private Integer urgencyDegree; // 紧急程度（1-一般，2-急，3-特急）
    private Integer securityClass; // 密级（1-公开，2-秘密，3-机密，4-绝密）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date planDate; // 安措费使用计划发文日期
    private BigDecimal planMny; // 拟投入金额
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectCode; // 项目code
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private Long parentOrgId; // 父级组织
    private String parentOrgName; // 父级组织名称
    private String parentOrgCode; // 父级组织编码
    private Long safeteamcId; // 安全小组主键
    private String safeteamcName; // 安全小组发文名称
    private String safeteamcBillCode; // 安全小组成立发文字号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date safeteamcDate; // 安全小组发文日期
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long submitEmployeeId; // 提交人
    private String submitEmployeeName; // 提交人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private String memo; // 安措费使用计发文说明
    private Integer billState; // 单据状态（审批必须字段）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date submitDate; // 提交日期
    private List<PlancDetailVO> plancDetailList = new ArrayList<>(); // 参会人员1


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }

    public Integer getUrgencyDegree() {
        return urgencyDegree;
    }

    public void setUrgencyDegree(Integer urgencyDegree) {
        this.urgencyDegree = urgencyDegree;
    }

    public Integer getSecurityClass() {
        return securityClass;
    }

    public void setSecurityClass(Integer securityClass) {
        this.securityClass = securityClass;
    }

    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }

    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    @ReferSerialTransfer(referCode = "safeTeam-c")
    public Long getSafeteamcId() {
        return safeteamcId;
    }

    @ReferDeserialTransfer
    public void setSafeteamcId(Long safeteamcId) {
        this.safeteamcId = safeteamcId;
    }

    public String getSafeteamcName() {
        return safeteamcName;
    }

    public void setSafeteamcName(String safeteamcName) {
        this.safeteamcName = safeteamcName;
    }

    public String getSafeteamcBillCode() {
        return safeteamcBillCode;
    }

    public void setSafeteamcBillCode(String safeteamcBillCode) {
        this.safeteamcBillCode = safeteamcBillCode;
    }

    public Date getSafeteamcDate() {
        return safeteamcDate;
    }

    public void setSafeteamcDate(Date safeteamcDate) {
        this.safeteamcDate = safeteamcDate;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getSubmitEmployeeId() {
        return submitEmployeeId;
    }

    public void setSubmitEmployeeId(Long submitEmployeeId) {
        this.submitEmployeeId = submitEmployeeId;
    }

    public String getSubmitEmployeeName() {
        return submitEmployeeName;
    }

    public void setSubmitEmployeeName(String submitEmployeeName) {
        this.submitEmployeeName = submitEmployeeName;
    }

    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    @ReferDeserialTransfer

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Date getSubmitDate() {
        return submitDate;
    }

    public void setSubmitDate(Date submitDate) {
        this.submitDate = submitDate;
    }

    public List<PlancDetailVO> getPlancDetailList() {
        return plancDetailList;
    }

    public void setPlancDetailList(List<PlancDetailVO> plancDetailList) {
        this.plancDetailList = plancDetailList;
    }
}
